@@ -3,6 +3,10 @@
 
 `%:::%` <- function (p, f) get(f, envir = asNamespace(p))
 
+viapply <- function(X, FUN, ..., USE.NAMES = TRUE) {
+  vapply(X, FUN, integer(1L), ..., USE.NAMES = USE.NAMES)
+}
+
 is_bioconductor <- function(x) {
   !is.null(x$biocviews)
 }
@@ -49,6 +53,14 @@ pkg_installed <- function(pkg) {
   }
 }
 
+has_package <- function(pkg) {
+  if (pkg %in% loadedNamespaces()) {
+    TRUE
+  } else {
+    requireNamespace(pkg, quietly = TRUE)
+  }
+}
+
 with_something <- function(set, reset = set) {
   function(new, code) {
     old <- set(new)
@@ -103,3 +115,15 @@ sys_type <- function() {
     stop("Unknown OS")
   }
 }
+
+is_dir <- function(path) {
+  file.info(path)$isdir
+}
+
+untar_description <- function(tarball, dir = tempfile()) {
+  files <- untar(tarball, list = TRUE)
+  desc <- grep("^[^/]+/DESCRIPTION$", files, value = TRUE)
+  if (length(desc) < 1) stop("No 'DESCRIPTION' file in package")
+  untar(tarball, desc, exdir = dir)
+  file.path(dir, desc)
+}
